package com.fzm.portal.controller;

import com.fzm.common.annotation.Authentication;
import com.fzm.common.entity.CopyrightApply;
import com.fzm.common.entity.dto.CopyrightDTO;
import com.fzm.common.entity.vo.CopyrightVo;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.service.CopyrightApplyService;
import com.fzm.common.utils.JwtUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author tangtuo
 * @date 2021/12/9 14:31
 */
@Authentication
@RestController
@Api(tags = "版权申请")
@RequestMapping("/copyright/apply")
public class CopyrightApplyController {

    @Resource
    private CopyrightApplyService copyrightApplyService;

    @PostMapping("/submit")
    @ApiModelProperty("/提交申请")
    public ResponseModel<Integer> submit(@RequestBody CopyrightDTO copyrightDTO) {
        Integer copyrightId = copyrightApplyService.submit(copyrightDTO);
        return ResponseModel.success(copyrightId);
    }


    @GetMapping("/list")
    @ApiOperation(value = "查询版权登记列表")
    public ResponseModel<List<CopyrightApply>> list(@RequestHeader(value = "Authorization") String token, @ApiParam("状态 0-全部 1-进行中 2-已完成") @RequestParam Integer state) {
        Integer userId = JwtUtil.getUserIdFromToken(token);
        List<CopyrightApply> list = copyrightApplyService.list(userId, state);
        return ResponseModel.success(list);
    }

    @PostMapping(value = "/reject")
    @ApiOperation(value = "驳回")
    public ResponseModel<Boolean> reject(@RequestParam Integer id) {
        Boolean result = copyrightApplyService.reject(id);
        return ResponseModel.success(result);
    }

    @PostMapping(value = "/delete")
    @ApiOperation(value = "删除")
    public ResponseModel<Boolean> delete(@RequestParam Integer id) {
        Boolean result = copyrightApplyService.delete(id);
        return ResponseModel.success(result);
    }

    @GetMapping(value = "/detail")
    @ApiOperation(value = "获取详情")
    public ResponseModel<CopyrightVo> getById(@RequestParam Integer id) {
        CopyrightVo copyrightVo = copyrightApplyService.getDetail(id);
        return ResponseModel.success(copyrightVo);
    }

}
